import { Pair } from '../../models/Pair';
import { Enumerable } from '../Enumerable';
var SelectorEqualityDictionary = /** @class */ (function () {
    function SelectorEqualityDictionary(keySelector) {
        this.keySelector = keySelector;
        this.source = new Map();
    }
    SelectorEqualityDictionary.prototype[Symbol.iterator] = function () {
        return this.source.values();
    };
    SelectorEqualityDictionary.prototype.clear = function () {
        this.source.clear();
    };
    SelectorEqualityDictionary.prototype.containsKey = function (key) {
        return this.source.has(this.keySelector(key));
    };
    SelectorEqualityDictionary.prototype.getPair = function (key) {
        return this.source.get(this.keySelector(key));
    };
    SelectorEqualityDictionary.prototype.getSize = function () {
        return this.source.size;
    };
    SelectorEqualityDictionary.prototype.keys = function () {
        return Enumerable.from(this.source.values())
            .select(function (x) { return x.key; });
    };
    SelectorEqualityDictionary.prototype.remove = function (key) {
        return this.source.delete(this.keySelector(key));
    };
    SelectorEqualityDictionary.prototype.set = function (key, value) {
        this.source.set(this.keySelector(key), Pair.from(key, value));
    };
    SelectorEqualityDictionary.prototype.values = function () {
        return Enumerable.from(this.source.values())
            .select(function (x) { return x.value; });
    };
    return SelectorEqualityDictionary;
}());
export { SelectorEqualityDictionary };
